/*                  MULTISERIES

    Con esta funcion dibujamos el grafico que aparecera en pantalla

	Argumentos:
	    s: Grafico de Lineas
	    l: Leyenda
	    lineas: El array con los valores true o false de los paises que queremos representar
	    archivo: archivo de datos
*/
function multiseries(s,l,lineas,archivo){

    /*Declaracion de los margenes y el area de dibujo*/
    var margin = {top: 50, right: 60, bottom: 30, left: 50},
        w = 680 - margin.left - 20,
        h = 400 - margin.top - margin.bottom;
    
    /*Escalas*/
    var x = d3.scale.linear().range([0,w]);
    var y = d3.scale.linear().range([h,0]);
    
    /*Ejes*/
    var xAxis = d3.svg.axis().scale(x).orient("bottom").ticks(5,"d");
    var yAxis = d3.svg.axis().scale(y).orient("left").ticks(10);
    
    /*Rejilla*/
    var yGrid = d3.svg.axis()
    .scale(y)
    .orient("left")
    .ticks(10)
    .tickSize(-w, 0, 0)
    .tickFormat("");
    
    var xGrid = d3.svg.axis()
    .scale(x)
    .orient("bottom")
    .ticks(5)
    .tickSize(h,0,0)
    .tickFormat("");
    
    /*Representamos el Indice de PIB en Suiza*/
    var switzerland = d3.svg.line()
        .x(function(d) { return x(d.Year);})
        .y(function(d) { return y(d.Switzerland);});
    
    /*Representamos el Indice de PIB en Islandia*/
    var iceland = d3.svg.line()
        .x(function(d) { return x(d.Year);})
        .y(function(d) { return y(d.Iceland);});
    
    /*Representamos el Indice de PIB en Dinamarca*/
    var denmark = d3.svg.line()
        .x(function(d) { return x(d.Year);})
        .y(function(d) { return y(d.Denmark);});
    
    /*/*Representamos el Indice de PIB en España*/
    var spain = d3.svg.line()
        .x(function(d) { return x(d.Year);})
        .y(function(d) { return y(d.Spain);});
    
    
    /*Creamos el svg donde dibujaremos el grafico*/
    var svg = d3.select(s)
        .append("svg")
        .attr("width", w + margin.left + margin.right)
        .attr("height", h + margin.top + margin.bottom)
        .append("g")
        .attr("transform", "translate(" + margin.left + ", " + margin.top + ")");
    
    /*Etiqueta del eje Y*/
    var labels = svg.append("g").attr("class", "labels");
    labels.append("text").attr("transform", "rotate(-90)").attr("y", -50).attr("dy", ".71em").attr("x",-20).style("text-anchor", "end").text("Indice PIB");
    
    /*Leyenda*/
    var leyenda = d3.select(l).append("svg").attr("width",500+margin.left+100).attr("height",50+margin.bottom);
    
    /*Añadimos Elementos de la Leyenda */
    leyenda.append('rect').attr('class','leyenda').attr('width',370).attr('height',44)
            .attr('x',100).attr('y',6);
    
    leyenda.append('rect').attr('width',15).attr('height',15).attr('x',94+20).attr('y',20).style('fill','gold');
          leyenda.append('text').attr('class','texto_leyenda').attr('x',94+40).attr('y',31).text("Suiza");
    
    leyenda.append('rect').attr('width',15).attr('height',15).attr('x',94+100).attr('y',20).style('fill','silver');
          leyenda.append('text').attr('class','texto_leyenda').attr('x',94+120).attr('y',31).text("Islandia");
    
    leyenda.append('rect').attr('width',15).attr('height',15).attr('x',94+190).attr('y',20).style('fill','brown');
          leyenda.append('text').attr('class','texto_leyenda').attr('x',94+210).attr('y',31).text("Dinamarca");
    
    leyenda.append('rect').attr('width',15).attr('height',15).attr('x',94+290).attr('y',20).style('fill','red');
          leyenda.append('text').attr('class','texto_leyenda').attr('x',94+310).attr('y',31).text("España");
    
    
    arch="datos_pib.csv";
    
    
    /*Leemos los datos .csv*/
    d3.csv(arch,function(error,data){
        data.forEach(function(d){
            d.Year=+d.Year;
            d.Switzerland=+d.Switzerland;
            d.Iceland=+d.Iceland;
            d.Denmark=+d.Denmark;
            d.Spain=+d.Spain;
        });
    
        /*Rango de los ejes*/
        x.domain([2015,2019]);
        y.domain([1200,1600]);
    
        /*Añadimos la rejilla*/
        svg.append("g")
        .attr("class", "grid")
        .call(yGrid);
        
        svg.append("g")
        .attr("class", "grid")
        .call(xGrid);
    
        /*GRAFICO DE LINEAS*/	
        
        /*Añadimos las lineas de cada pais*/
        if(lineas[0]==true){
        svg.append("path")	
        .attr("class", "line")
        .style("stroke", "gold")
        .style("stroke-width",2.8)
        .attr("d", switzerland(data));
        }
        
        if(lineas[1]==true){
        svg.append("path")	
        .attr("class", "line")
        .style("stroke", "silver")
        .style("stroke-width",2.8)
        .attr("d", iceland(data));
        }
    
        if(lineas[2]==true){	
        svg.append("path")	
        .attr("class", "line")
        .style("stroke", "brown")
        .style("stroke-width",2.8)
        .attr("d", denmark(data));
        }
    
        if(lineas[3]==true){
        svg.append("path")	
        .attr("class", "line")
        .style("stroke", "red")
        .style("stroke-width",2.8)
        .attr("d", spain(data));
        }
    
        /*Añadimos Puntos en el grafico de lineas*/
        /*Cuando se pase por encima con el raton aparece una leyenda mostrando su Indice de PIB en ese año*/
    
        if(lineas[0]==true){
        svg.selectAll("dot")
            .data(data)
        .enter().append("circle")
            .attr("r", 5)
            .attr("cx", function(d) { return x(d.Year); })
            .attr("cy", function(d) { return y(d.Switzerland); })
        .style("fill","gold")
        .on("mouseover", ratonSuiza)
            .on("mouseout", eliminarEventoRaton);
        }
        
        if(lineas[1]==true){
        svg.selectAll("dot")
            .data(data)
        .enter().append("circle")
            .attr("r", 5)
            .attr("cx", function(d) { return x(d.Year); })
            .attr("cy", function(d) { return y(d.Iceland); })
        .style("fill","silver")
        .on("mouseover", ratonIslandia)
            .on("mouseout", eliminarEventoRaton);
        }
    
        if(lineas[2]==true){
        svg.selectAll("dot")
            .data(data)
        .enter().append("circle")
            .attr("r", 5)
            .attr("cx", function(d) { return x(d.Year); })
            .attr("cy", function(d) { return y(d.Denmark); })
        .style("fill","brown")
        .on("mouseover", ratonDinamarca)
            .on("mouseout", eliminarEventoRaton);
        }
    
        if(lineas[3]==true){
        svg.selectAll("dot")
            .data(data)
        .enter().append("circle")
            .attr("r", 5)
            .attr("cx", function(d) { return x(d.Year); })
            .attr("cy", function(d) { return y(d.Spain); })
        .style("fill","red")
        .on("mouseover", ratonEspaña)
            .on("mouseout", eliminarEventoRaton);
        }
    
        /*Añadimos el eje x*/
        svg.append("g")			
        .attr("class", "x axis")
        .attr("transform", "translate(0," + h + ")")
        .call(xAxis);
    
        /*Añadimos el eje y*/
        svg.append("g")			
        .attr("class", "y axis")
        .call(yAxis);
    
        var title = svg.append("g").attr("class","title")
         
        /*Añadimos el título*/
          title.append("text")
            .attr("x", (w / 2))
            .attr("y", -20 )
                  .attr("text-anchor", "middle")  
                  .style("font-size", "22px") 
                  .text("Evolución Indice PIB per capita");
    
    });
    
    /*EVENTOS DE RATON*/
    
    /*Cuando el Raton pasa por encima de un punto se muestra en un recuadro el Indice de PIB correspondiente en ese año*/
    
    function ratonSuiza(d, i) {
        svg.append("rect")
        .style("stroke",'black')
        .attr("x",x(d.Year)-18)
        .attr("y",y(d.Switzerland)-26)
        .attr("width",70)
        .attr("height",15)
        .attr("fill","white")
        .attr("id","r" + d.x + "-" + d.y + "-" + i);
        svg.append("text").attr({
            id: "t" + d.x + "-" + d.y + "-" + i,  
            x: function() { return x(d.Year) - 15; },
            y: function() { return y(d.Switzerland) - 15; }
            })
            .text(function() {
                  return [`Indice: ${d.Switzerland}`];  
             });
    }
    
    function ratonIslandia(d, i) {
        svg.append("rect")
        .style("stroke",'black')
        .attr("x",x(d.Year)-18)
        .attr("y",y(d.Iceland)-26)
        .attr("width",70)
        .attr("height",15)
        .attr("fill","white")
        .attr("id","r" + d.x + "-" + d.y + "-" + i);
        svg.append("text").attr({
            id: "t" + d.x + "-" + d.y + "-" + i,  
            x: function() { return x(d.Year) - 15; },
            y: function() { return y(d.Iceland) - 15; }
            })
            .text(function() {
                  return [`Indice: ${d.Iceland}`];  
             });
    }
    
    function ratonDinamarca(d, i) {
        svg.append("rect")
        .style("stroke",'black')
        .attr("x",x(d.Year)-18)
        .attr("y",y(d.Denmark)-26)
        .attr("width",70)
        .attr("height",15)
        .attr("fill","white")
        .attr("id","r" + d.x + "-" + d.y + "-" + i);
        svg.append("text").attr({
            id: "t" + d.x + "-" + d.y + "-" + i,  
            x: function() { return x(d.Year) - 15; },
            y: function() { return y(d.Denmark) - 15; }
            })
            .text(function() {
                  return [`Indice: ${d.Denmark}`];  
             });
    }
    
    function ratonEspaña(d, i) {
        svg.append("rect")
        .style("stroke",'black')
        .attr("x",x(d.Year)-18)
        .attr("y",y(d.Spain)-26)
        .attr("width",70)
        .attr("height",15)
        .attr("fill","white")
        .attr("id","r" + d.x + "-" + d.y + "-" + i);
        svg.append("text").attr({
            id: "t" + d.x + "-" + d.y + "-" + i,  
            x: function() { return x(d.Year) - 15; },
            y: function() { return y(d.Spain) - 15; }
            })
            .text(function() {
                  return [`Indice: ${d.Spain}`];  
             });
    }
    
    function eliminarEventoRaton(d, i) {
        d3.select("#t" + d.x + "-" + d.y + "-" + i).remove();
        d3.select("#r" + d.x + "-" + d.y + "-" + i).remove();
    }
    
    }
    